@@ -21,9 +21,9 @@ from django.db import models, transaction
 from django.db.models import QuerySet, Q
 from django.utils.timezone import now
 from jutil.cache import CachedFieldsMixin
-from jutil.dict import choices_label
 from django.utils.translation import gettext_lazy as _
 
+from jutil.format import choices_label
 from jutil.modelfields import SafeCharField, SafeTextField
 
 CATEGORY_ANY = ''
